@@ -76,8 +76,8 @@ class Element:
 
     def __getattr__(self, name: str) -> Any:
         ''' Allow getting anchor position as attribute '''
-        if name in self.absanchors.keys():
-            return self.absanchors[name]
+        if name in vars(self).get('absanchors', {}):
+            return vars(self).get('absanchors')[name]  # type: ignore
         raise AttributeError(f'{name} not defined in Element')
 
     def up(self) -> 'Element':
@@ -446,19 +446,25 @@ class Element:
 
         if loc is None:
             loc = self._cparams.get('lblloc', 'top')
-        loc = {'bottom': 'bot', 'left': 'lft', 'right': 'rgt'}.get(loc, loc)  # type: ignore
+        loc = {'bot': 'bottom',
+               'B': 'bottom',
+               'lft': 'left',
+               'L': 'left',
+               'rgt': 'right',
+               'R': 'right',
+               'T': 'top'}.get(loc, loc)  # type: ignore
 
         # This ensures a 'top' label is always on top, regardless of rotation
         theta = self.transform.theta
         if (theta % 360) > 90 and (theta % 360) <= 270:
             if loc == 'top':
-                loc = 'bot'
-            elif loc == 'bot':
+                loc = 'bottom'
+            elif loc == 'bottom':
                 loc = 'top'
-            elif loc == 'lft':
-                loc = 'rgt'
-            elif loc == 'rgt':
-                loc = 'lft'
+            elif loc == 'left':
+                loc = 'right'
+            elif loc == 'right':
+                loc = 'left'
 
         if align is None and loc == 'center' and isinstance(label, (list, tuple)):
             align = ('center', 'center')
@@ -467,11 +473,11 @@ class Element:
         if None in align:   # Determine best alignment for label based on angle
             th = theta - rotation
             # Below alignment divisions work for label on top. Rotate angle for other sides.
-            if loc == 'lft':
+            if loc == 'left':
                 th = th + 90
-            elif loc == 'bot':
+            elif loc == 'bottom':
                 th = th + 180
-            elif loc == 'rgt':
+            elif loc == 'right':
                 th = th + 270
             th = (th+360) % 360  # Normalize angle so it's positive, clockwise
 
@@ -561,19 +567,19 @@ class Element:
                 for i, lbltxt in enumerate(label):
                     xy = Point((xmin+xdiv*(i+1), ymax))
                     self.segments.append(SegmentText(xy+ofst, lbltxt, **lblparams))
-            elif loc == 'bot':
+            elif loc == 'bottom':
                 xdiv = (xmax-xmin)/(len(label)+1)
                 ofst = Point((0, -ofst)) if not isinstance(ofst, (list, tuple)) else Point(ofst)
                 for i, lbltxt in enumerate(label):
                     xy = Point((xmin+xdiv*(i+1), ymin))
                     self.segments.append(SegmentText(xy+ofst, lbltxt, **lblparams))
-            elif loc == 'lft':
+            elif loc == 'left':
                 ydiv = (ymax-ymin)/(len(label)+1)
                 ofst = Point((-ofst, 0)) if not isinstance(ofst, (list, tuple)) else Point(ofst)
                 for i, lbltxt in enumerate(label):
                     xy = Point((xmin, ymin+ydiv*(i+1)))
                     self.segments.append(SegmentText(xy+ofst, lbltxt, **lblparams))
-            elif loc == 'rgt':
+            elif loc == 'right':
                 ydiv = (ymax-ymin)/(len(label)+1)
                 ofst = Point((ofst, 0)) if not isinstance(ofst, (list, tuple)) else Point(ofst)
                 for i, lbltxt in enumerate(label):
@@ -591,13 +597,13 @@ class Element:
             if loc == 'top':
                 ofst = Point((0, ofst)) if not isinstance(ofst, (list, tuple)) else Point(ofst)
                 xy = Point(((xmax+xmin)/2, ymax))
-            elif loc == 'bot':
+            elif loc == 'bottom':
                 ofst = Point((0, -ofst)) if not isinstance(ofst, (list, tuple)) else Point(ofst)  # type: ignore
                 xy = Point(((xmax+xmin)/2, ymin))
-            elif loc == 'lft':
+            elif loc == 'left':
                 ofst = Point((-ofst, 0)) if not isinstance(ofst, (list, tuple)) else Point(ofst)  # type: ignore
                 xy = Point((xmin, (ymax+ymin)/2))
-            elif loc == 'rgt':
+            elif loc == 'right':
                 ofst = Point((ofst, 0)) if not isinstance(ofst, (list, tuple)) else Point(ofst)
                 xy = Point((xmax, (ymax+ymin)/2))
             elif loc == 'center':
@@ -742,7 +748,6 @@ class Element2Term(Element):
             endpt = [xy[0], y]
             totlen = util.dist(xy, endpt)
 
-        self._localshift = Point((0, 0))
         if self._cparams.get('extend', True):
             in_path = self.segments[0].path  # type: ignore
             dz = util.delta(in_path[-1], in_path[0])   # Defined delta of path
@@ -760,13 +765,22 @@ class Element2Term(Element):
                 end = Point(in_path[-1])
                 self._localshift = Point((0, 0))
 
+            # Adjust position of endpoints (arrowheads, dots, etc.)
+            for i in range(len(self.segments)):
+                if getattr(self.segments[i], 'endref', None) == 'end':
+                    xform = Transform(0, end)
+                    self.segments[i] = self.segments[i].xform(xform)
+                elif getattr(self.segments[i], 'endref', None) == 'start':
+                    xform = Transform(0, start)
+                    self.segments[i] = self.segments[i].xform(xform)
+
         self.anchors['start'] = Point(start)
         self.anchors['end'] = Point(end)
         self.anchors['center'] = (start+end)/2
 
         if anchor is not None:
-            self._localshift = -Point(self.anchors[anchor])
-        transform = Transform(theta, xy, self._localshift, zoom)
+            self._localshift = self._localshift-Point(self.anchors[anchor])
+        transform = Transform(theta, xy, self._localshift, zoom=zoom)
 
         self.absanchors = {}
         if len(self.segments) == 0:
